@@ -27,6 +27,9 @@ class Helper:
       elif arg == "--name":
         i += 1
         options["name"] = self.argv[i]
+      elif arg == "--unix_socket":
+        i += 1
+        options["unix_socket"] = self.argv[i]
       elif arg == "--host":
         i += 1
         options["host"] = self.argv[i]
